# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ServiceTypeCode(str, enum.Enum):
    """
    Code identifying the type of service or benefit within a specific insurance policy (X12 008010 Element 1365)
    """

    MEDICAL_CARE = "1"
    """
    Medical Care
    """

    SURGICAL = "2"
    """
    Surgical
    """

    CONSULTATION = "3"
    """
    Consultation
    """

    DIAGNOSTIC_X_RAY = "4"
    """
    Diagnostic X-Ray
    """

    DIAGNOSTIC_LAB = "5"
    """
    Diagnostic Lab
    """

    RADIATION_THERAPY = "6"
    """
    Radiation Therapy
    """

    ANESTHESIA = "7"
    """
    Anesthesia
    """

    SURGICAL_ASSISTANCE = "8"
    """
    Surgical Assistance
    """

    OTHER_MEDICAL = "9"
    """
    Other Medical
    """

    BLOOD_CHARGES = "10"
    """
    Blood Charges
    """

    USED_DURABLE_MEDICAL_EQUIPMENT = "11"
    """
    Used Durable Medical Equipment
    """

    DURABLE_MEDICAL_EQUIPMENT_PURCHASE = "12"
    """
    Durable Medical Equipment Purchase
    """

    AMBULATORY_SURGICAL_CENTER_FACILITY = "13"
    """
    Ambulatory Service Center Facility
    """

    RENAL_SUPPLIES_IN_HOME = "14"
    """
    Renal Supplies in the Home
    """

    ALTERNATE_METHOD_DIALYSIS = "15"
    """
    Alternate Method Dialysis
    """

    CHRONIC_RENAL_DISEASE_EQUIPMENT = "16"
    """
    Chronic Renal Disease (CRD) Equipment
    """

    PRE_ADMISSION_TESTING = "17"
    """
    Pre-Admission Testing
    """

    DURABLE_MEDICAL_EQUIPMENT_RENTAL = "18"
    """
    Durable Medical Equipment Rental
    """

    PNEUMONIA_VACCINE = "19"
    """
    Pneumonia Vaccine
    """

    SECOND_SURGICAL_OPINION = "20"
    """
    Second Surgical Opinion
    """

    THIRD_SURGICAL_OPINION = "21"
    """
    Third Surgical Opinion
    """

    SOCIAL_WORK = "22"
    """
    Social Work
    """

    DIAGNOSTIC_DENTAL = "23"
    """
    Diagnostic Dental
    """

    PERIODONTICS = "24"
    """
    Periodontics
    """

    RESTORATIVE = "25"
    """
    Restorative
    """

    ENDODONTICS = "26"
    """
    Endodontics
    """

    MAXILLOFACIAL_PROSTHETICS = "27"
    """
    Maxillofacial Prosthetics
    """

    ADJUNCTIVE_DENTAL_SERVICES = "28"
    """
    Adjunctive Dental Services
    """

    HEALTH_BENEFIT_PLAN_COVERAGE = "30"
    """
    Health Benefit Plan Coverage
    """

    PLAN_WAITING_PERIOD = "32"
    """
    Plan Waiting Period
    """

    CHIROPRACTIC = "33"
    """
    Chiropractic
    """

    CHIROPRACTIC_OFFICE_VISITS = "34"
    """
    Chiropractic Office Visits
    """

    DENTAL_CARE = "35"
    """
    Dental Care
    """

    DENTAL_CROWNS = "36"
    """
    Dental Crowns
    """

    DENTAL_ACCIDENT = "37"
    """
    Dental Accident
    """

    ORTHODONTICS = "38"
    """
    Orthodontics
    """

    PROSTHODONTICS = "39"
    """
    Prosthodontics
    """

    ORAL_SURGERY = "40"
    """
    Oral Surgery
    """

    ROUTINE_PREVENTIVE_DENTAL = "41"
    """
    Routine (Preventive) Dental
    """

    HOME_HEALTH_CARE = "42"
    """
    Home Health Care
    """

    HOME_HEALTH_PRESCRIPTIONS = "43"
    """
    Home Health Prescriptions
    """

    HOME_HEALTH_VISITS = "44"
    """
    Home Health Visits
    """

    HOSPICE = "45"
    """
    Hospice
    """

    RESPITE_CARE = "46"
    """
    Respite Care
    """

    HOSPITAL = "47"
    """
    Hospital
    """

    HOSPITAL_INPATIENT = "48"
    """
    Hospital - Inpatient
    """

    HOSPITAL_ROOM_AND_BOARD = "49"
    """
    Hospital - Room and Board
    """

    HOSPITAL_OUTPATIENT = "50"
    """
    Hospital - Outpatient
    """

    HOSPITAL_EMERGENCY_ACCIDENT = "51"
    """
    Hospital - Emergency Accident
    """

    HOSPITAL_EMERGENCY_MEDICAL = "52"
    """
    Hospital - Emergency Medical
    """

    HOSPITAL_AMBULATORY_SURGICAL = "53"
    """
    Hospital - Ambulatory Surgical
    """

    LONG_TERM_CARE = "54"
    """
    Long Term Care
    """

    MAJOR_MEDICAL = "55"
    """
    Major Medical
    """

    MEDICALLY_RELATED_TRANSPORTATION = "56"
    """
    Medically Related Transportation
    """

    AIR_TRANSPORTATION = "57"
    """
    Air Transportation
    """

    CABULANCE = "58"
    """
    Cabulance
    """

    LICENSED_AMBULANCE = "59"
    """
    Licensed Ambulance
    """

    GENERAL_BENEFITS = "60"
    """
    General Benefits
    """

    IN_VITRO_FERTILIZATION = "61"
    """
    In-vitro Fertilization
    """

    MRICAT_SCAN = "62"
    """
    MRI/CAT Scan
    """

    DONOR_PROCEDURES = "63"
    """
    Donor Procedures
    """

    ACUPUNCTURE = "64"
    """
    Acupuncture
    """

    NEWBORN_CARE = "65"
    """
    Newborn Care
    """

    PATHOLOGY = "66"
    """
    Pathology
    """

    SMOKING_CESSATION = "67"
    """
    Smoking Cessation
    """

    WELL_BABY_CARE = "68"
    """
    Well Baby Care
    """

    MATERNITY = "69"
    """
    Maternity
    """

    TRANSPLANTS = "70"
    """
    Transplants
    """

    AUDIOLOGY_EXAM = "71"
    """
    Audiology Exam
    """

    INHALATION_THERAPY = "72"
    """
    Inhalation Therapy
    """

    DIAGNOSTIC_MEDICAL = "73"
    """
    Diagnostic Medical
    """

    PRIVATE_DUTY_NURSING = "74"
    """
    Private Duty Nursing
    """

    PROSTHETIC_DEVICE = "75"
    """
    Prosthetic Device
    """

    DIALYSIS = "76"
    """
    Dialysis
    """

    OTOLOGICAL_EXAM = "77"
    """
    Otological Exam
    """

    CHEMOTHERAPY = "78"
    """
    Chemotherapy
    """

    ALLERGY_TESTING = "79"
    """
    Allergy Testing
    """

    IMMUNIZATIONS = "80"
    """
    Immunizations
    """

    ROUTINE_PHYSICAL = "81"
    """
    Routine Physical
    """

    FAMILY_PLANNING = "82"
    """
    Family Planning
    """

    INFERTILITY = "83"
    """
    Infertility
    """

    ABORTION = "84"
    """
    Abortion
    """

    AIDS = "85"
    """
    AIDS
    """

    EMERGENCY_SERVICES = "86"
    """
    Emergency Services
    """

    CANCER = "87"
    """
    Cancer
    """

    PHARMACY = "88"
    """
    Pharmacy
    """

    FREE_STANDING_PRESCRIPTION_DRUG = "89"
    """
    Free Standing Prescription Drug
    """

    MAIL_ORDER_PRESCRIPTION_DRUG = "90"
    """
    Mail Order Prescription Drug
    """

    BRAND_NAME_PRESCRIPTION_DRUG = "91"
    """
    Brand Name Prescription Drug
    """

    GENERIC_PRESCRIPTION_DRUG = "92"
    """
    Generic Prescription Drug
    """

    PODIATRY = "93"
    """
    Podiatry
    """

    PODIATRY_OFFICE_VISITS = "94"
    """
    Podiatry - Office Visits
    """

    PODIATRY_NURSING_HOME_VISITS = "95"
    """
    Podiatry - Nursing Home Visits
    """

    PROFESSIONAL_PHYSICIAN = "96"
    """
    Professional (Physician)
    """

    ANESTHESIOLOGIST = "97"
    """
    Anesthesiologist
    """

    PROFESSIONAL_PHYSICIAN_VISIT_OFFICE = "98"
    """
    Professional (Physician) Visit - Office
    """

    PROFESSIONAL_PHYSICIAN_VISIT_INPATIENT = "99"
    """
    Professional (Physician) Visit - Inpatient
    """

    PROFESSIONAL_PHYSICIAN_VISIT_OUTPATIENT = "A0"
    """
    Professional (Physician) Visit - Outpatient
    """

    PROFESSIONAL_PHYSICIAN_VISIT_NURSING_HOME = "A1"
    """
    Professional (Physician) Visit - Nursing Home
    """

    PROFESSIONAL_PHYSICIAN_VISIT_SKILLED_NURSING_FACILITY = "A2"
    """
    Professional (Physician) Visit - Skilled Nursing Facility
    """

    PROFESSIONAL_PHYSICIAN_VISIT_HOME = "A3"
    """
    Professional (Physician) Visit - Home
    """

    PSYCHIATRIC = "A4"
    """
    Psychiatric
    """

    PSYCHIATRIC_ROOM_AND_BOARD = "A5"
    """
    Psychiatric - Room and Board
    """

    PSYCHOTHERAPY = "A6"
    """
    Psychotherapy
    """

    PSYCHIATRIC_INPATIENT = "A7"
    """
    Psychiatric - Inpatient
    """

    PSYCHIATRIC_OUTPATIENT = "A8"
    """
    Psychiatric - Outpatient
    """

    REHABILITATION = "A9"
    """
    Rehabilitation
    """

    REHABILITATION_ROOM_AND_BOARD = "AA"
    """
    Rehabilitation - Room and Board
    """

    REHABILITATION_INPATIENT = "AB"
    """
    Rehabilitation - Inpatient
    """

    REHABILITATION_OUTPATIENT = "AC"
    """
    Rehabilitation - Outpatient
    """

    OCCUPATIONAL_THERAPY = "AD"
    """
    Occupational Therapy
    """

    PHYSICAL_MEDICINE = "AE"
    """
    Physical Medicine
    """

    SPEECH_THERAPY = "AF"
    """
    Speech Therapy
    """

    SKILLED_NURSING_CARE = "AG"
    """
    Skilled Nursing Care
    """

    SKILLED_NURSING_CARE_ROOM_AND_BOARD = "AH"
    """
    Skilled Nursing Care - Room and Board
    """

    SUBSTANCE_ABUSE = "AI"
    """
    Substance Abuse
    """

    ALCOHOLISM = "AJ"
    """
    Alcoholism
    """

    DRUG_ADDICTION = "AK"
    """
    Drug Addiction
    """

    VISION_OPTOMETRY = "AL"
    """
    Vision (Optometry)
    """

    FRAMES = "AM"
    """
    Frames
    """

    ROUTINE_EXAM = "AN"
    """
    Routine Exam
    """

    LENSES = "AO"
    """
    Lenses
    """

    NONMEDICALLY_NECESSARY_PHYSICAL = "AQ"
    """
    Nonmedically Necessary Physical
    """

    EXPERIMENTAL_DRUG_THERAPY = "AR"
    """
    Experimental Drug Therapy
    """

    BURN_CARE = "B1"
    """
    Burn Care
    """

    BRAND_NAME_PRESCRIPTION_DRUG_FORMULARY = "B2"
    """
    Brand Name Prescription Drug - Formulary
    """

    BRAND_NAME_PRESCRIPTION_DRUG_NON_FORMULARY = "B3"
    """
    Brand Name Prescription Drug - Non-Formulary
    """

    INDEPENDENT_MEDICAL_EVALUATION = "BA"
    """
    Independent Medical Evaluation
    """

    PARTIAL_HOSPITALIZATION_PSYCHIATRIC = "BB"
    """
    Partial Hospitalization (Psychiatric)
    """

    DAY_CARE_PSYCHIATRIC = "BC"
    """
    Day Care (Psychiatric)
    """

    COGNITIVE_THERAPY = "BD"
    """
    Cognitive Therapy
    """

    MASSAGE_THERAPY = "BE"
    """
    Massage Therapy
    """

    PULMONARY_REHABILITATION = "BF"
    """
    Pulmonary Rehabilitation
    """

    CARDIAC_REHABILITATION = "BG"
    """
    Cardiac Rehabilitation
    """

    PEDIATRIC = "BH"
    """
    Pediatric
    """

    NURSERY = "BI"
    """
    Nursery
    """

    SKIN = "BJ"
    """
    Skin
    """

    ORTHOPEDIC = "BK"
    """
    Orthopedic
    """

    CARDIAC = "BL"
    """
    Cardiac
    """

    LYMPHATIC = "BM"
    """
    Lymphatic
    """

    GASTROINTESTINAL = "BN"
    """
    Gastrointestinal
    """

    ENDOCRINE = "BP"
    """
    Endocrine
    """

    NEUROLOGY = "BQ"
    """
    Neurology
    """

    EYE = "BR"
    """
    Eye
    """

    INVASIVE_PROCEDURES = "BS"
    """
    Invasive Procedures
    """

    GYNECOLOGICAL = "BT"
    """
    Gynecological
    """

    OBSTETRICAL = "BU"
    """
    Obstetrical
    """

    OBSTETRICAL_GYNECOLOGICAL = "BV"
    """
    Obstetrical/Gynecological
    """

    MAIL_ORDER_PRESCRIPTION_DRUG_BRAND_NAME = "BW"
    """
    Mail Order Prescription Drug - Brand Name
    """

    MAIL_ORDER_PRESCRIPTION_DRUG_GENERIC = "BX"
    """
    Mail Order Prescription Drug - Generic
    """

    PHYSICIAN_VISIT_OFFICE_SICK = "BY"
    """
    Physician Visit - Office - Sick
    """

    PHYSICIAN_VISIT_OFFICE_WELL = "BZ"
    """
    Physician Visit - Office - Well
    """

    CORONARY_CARE = "C1"
    """
    Coronary Care
    """

    PRIVATE_DUTY_NURSING_INPATIENT = "CA"
    """
    Private Duty Nursing - Inpatient
    """

    PRIVATE_DUTY_NURSING_HOME = "CB"
    """
    Private Duty Nursing - Home
    """

    SURGICAL_BENEFITS_PROFESSIONAL_PHYSICIAN = "CC"
    """
    Surgical Benefits - Professional (Physician)
    """

    SURGICAL_BENEFITS_FACILITY = "CD"
    """
    Surgical Benefits - Facility
    """

    MENTAL_HEALTH_PROVIDER_INPATIENT = "CE"
    """
    Mental Health Provider - Inpatient
    """

    MENTAL_HEALTH_PROVIDER_OUTPATIENT = "CF"
    """
    Mental Health Provider - Outpatient
    """

    MENTAL_HEALTH_FACILITY_INPATIENT = "CG"
    """
    Mental Health Facility - Inpatient
    """

    MENTAL_HEALTH_FACILITY_OUTPATIENT = "CH"
    """
    Mental Health Facility - Outpatient
    """

    SUBSTANCE_ABUSE_FACILITY_INPATIENT = "CI"
    """
    Substance Abuse Facility - Inpatient
    """

    SUBSTANCE_ABUSE_FACILITY_OUTPATIENT = "CJ"
    """
    Substance Abuse Facility - Outpatient
    """

    SCREENING_X_RAY = "CK"
    """
    Screening X-ray
    """

    SCREENING_LABORATORY = "CL"
    """
    Screening laboratory
    """

    MAMMOGRAM_HIGH_RISK_PATIENT = "CM"
    """
    Mammogram, High Risk Patient
    """

    MAMMOGRAM_LOW_RISK_PATIENT = "CN"
    """
    Mammogram, Low Risk Patient
    """

    FLU_VACCINATION = "CO"
    """
    Flu Vaccination
    """

    EYEWEAR_AND_EYEWEAR_ACCESSORIES = "CP"
    """
    Eyewear and Eyewear Accessories
    """

    CASE_MANAGEMENT = "CQ"
    """
    Case Management
    """

    DERMATOLOGY = "DG"
    """
    Dermatology
    """

    DURABLE_MEDICAL_EQUIPMENT = "DM"
    """
    Durable Medical Equipment
    """

    DIABETIC_SUPPLIES = "DS"
    """
    Diabetic Supplies
    """

    GENERIC_PRESCRIPTION_DRUG_FORMULARY = "GF"
    """
    Generic Prescription Drug - Formulary
    """

    GENERIC_PRESCRIPTION_DRUG_NON_FORMULARY = "GN"
    """
    Generic Prescription Drug - Non-Formulary
    """

    ALLERGY = "GY"
    """
    Allergy
    """

    INTENSIVE_CARE = "IC"
    """
    Intensive Care
    """

    MENTAL_HEALTH = "MH"
    """
    Mental Health
    """

    NEONATAL_INTENSIVE_CARE = "NI"
    """
    Neonatal Intensive Care
    """

    ONCOLOGY = "ON"
    """
    Oncology
    """

    PHYSICAL_THERAPY = "PT"
    """
    Physical Therapy
    """

    PULMONARY = "PU"
    """
    Pulmonary
    """

    RENAL = "RN"
    """
    Renal
    """

    RESIDENTIAL_PSYCHIATRIC_TREATMENT = "RT"
    """
    Residential Psychiatric Treatment
    """

    TRANSITIONAL_CARE = "TC"
    """
    Transitional Care
    """

    TRANSITIONAL_NURSERY_CARE = "TN"
    """
    Transitional Nursery Care
    """

    URGENT_CARE = "UC"
    """
    Urgent Care
    """

    def visit(
        self,
        medical_care: typing.Callable[[], T_Result],
        surgical: typing.Callable[[], T_Result],
        consultation: typing.Callable[[], T_Result],
        diagnostic_x_ray: typing.Callable[[], T_Result],
        diagnostic_lab: typing.Callable[[], T_Result],
        radiation_therapy: typing.Callable[[], T_Result],
        anesthesia: typing.Callable[[], T_Result],
        surgical_assistance: typing.Callable[[], T_Result],
        other_medical: typing.Callable[[], T_Result],
        blood_charges: typing.Callable[[], T_Result],
        used_durable_medical_equipment: typing.Callable[[], T_Result],
        durable_medical_equipment_purchase: typing.Callable[[], T_Result],
        ambulatory_surgical_center_facility: typing.Callable[[], T_Result],
        renal_supplies_in_home: typing.Callable[[], T_Result],
        alternate_method_dialysis: typing.Callable[[], T_Result],
        chronic_renal_disease_equipment: typing.Callable[[], T_Result],
        pre_admission_testing: typing.Callable[[], T_Result],
        durable_medical_equipment_rental: typing.Callable[[], T_Result],
        pneumonia_vaccine: typing.Callable[[], T_Result],
        second_surgical_opinion: typing.Callable[[], T_Result],
        third_surgical_opinion: typing.Callable[[], T_Result],
        social_work: typing.Callable[[], T_Result],
        diagnostic_dental: typing.Callable[[], T_Result],
        periodontics: typing.Callable[[], T_Result],
        restorative: typing.Callable[[], T_Result],
        endodontics: typing.Callable[[], T_Result],
        maxillofacial_prosthetics: typing.Callable[[], T_Result],
        adjunctive_dental_services: typing.Callable[[], T_Result],
        health_benefit_plan_coverage: typing.Callable[[], T_Result],
        plan_waiting_period: typing.Callable[[], T_Result],
        chiropractic: typing.Callable[[], T_Result],
        chiropractic_office_visits: typing.Callable[[], T_Result],
        dental_care: typing.Callable[[], T_Result],
        dental_crowns: typing.Callable[[], T_Result],
        dental_accident: typing.Callable[[], T_Result],
        orthodontics: typing.Callable[[], T_Result],
        prosthodontics: typing.Callable[[], T_Result],
        oral_surgery: typing.Callable[[], T_Result],
        routine_preventive_dental: typing.Callable[[], T_Result],
        home_health_care: typing.Callable[[], T_Result],
        home_health_prescriptions: typing.Callable[[], T_Result],
        home_health_visits: typing.Callable[[], T_Result],
        hospice: typing.Callable[[], T_Result],
        respite_care: typing.Callable[[], T_Result],
        hospital: typing.Callable[[], T_Result],
        hospital_inpatient: typing.Callable[[], T_Result],
        hospital_room_and_board: typing.Callable[[], T_Result],
        hospital_outpatient: typing.Callable[[], T_Result],
        hospital_emergency_accident: typing.Callable[[], T_Result],
        hospital_emergency_medical: typing.Callable[[], T_Result],
        hospital_ambulatory_surgical: typing.Callable[[], T_Result],
        long_term_care: typing.Callable[[], T_Result],
        major_medical: typing.Callable[[], T_Result],
        medically_related_transportation: typing.Callable[[], T_Result],
        air_transportation: typing.Callable[[], T_Result],
        cabulance: typing.Callable[[], T_Result],
        licensed_ambulance: typing.Callable[[], T_Result],
        general_benefits: typing.Callable[[], T_Result],
        in_vitro_fertilization: typing.Callable[[], T_Result],
        mricat_scan: typing.Callable[[], T_Result],
        donor_procedures: typing.Callable[[], T_Result],
        acupuncture: typing.Callable[[], T_Result],
        newborn_care: typing.Callable[[], T_Result],
        pathology: typing.Callable[[], T_Result],
        smoking_cessation: typing.Callable[[], T_Result],
        well_baby_care: typing.Callable[[], T_Result],
        maternity: typing.Callable[[], T_Result],
        transplants: typing.Callable[[], T_Result],
        audiology_exam: typing.Callable[[], T_Result],
        inhalation_therapy: typing.Callable[[], T_Result],
        diagnostic_medical: typing.Callable[[], T_Result],
        private_duty_nursing: typing.Callable[[], T_Result],
        prosthetic_device: typing.Callable[[], T_Result],
        dialysis: typing.Callable[[], T_Result],
        otological_exam: typing.Callable[[], T_Result],
        chemotherapy: typing.Callable[[], T_Result],
        allergy_testing: typing.Callable[[], T_Result],
        immunizations: typing.Callable[[], T_Result],
        routine_physical: typing.Callable[[], T_Result],
        family_planning: typing.Callable[[], T_Result],
        infertility: typing.Callable[[], T_Result],
        abortion: typing.Callable[[], T_Result],
        aids: typing.Callable[[], T_Result],
        emergency_services: typing.Callable[[], T_Result],
        cancer: typing.Callable[[], T_Result],
        pharmacy: typing.Callable[[], T_Result],
        free_standing_prescription_drug: typing.Callable[[], T_Result],
        mail_order_prescription_drug: typing.Callable[[], T_Result],
        brand_name_prescription_drug: typing.Callable[[], T_Result],
        generic_prescription_drug: typing.Callable[[], T_Result],
        podiatry: typing.Callable[[], T_Result],
        podiatry_office_visits: typing.Callable[[], T_Result],
        podiatry_nursing_home_visits: typing.Callable[[], T_Result],
        professional_physician: typing.Callable[[], T_Result],
        anesthesiologist: typing.Callable[[], T_Result],
        professional_physician_visit_office: typing.Callable[[], T_Result],
        professional_physician_visit_inpatient: typing.Callable[[], T_Result],
        professional_physician_visit_outpatient: typing.Callable[[], T_Result],
        professional_physician_visit_nursing_home: typing.Callable[[], T_Result],
        professional_physician_visit_skilled_nursing_facility: typing.Callable[[], T_Result],
        professional_physician_visit_home: typing.Callable[[], T_Result],
        psychiatric: typing.Callable[[], T_Result],
        psychiatric_room_and_board: typing.Callable[[], T_Result],
        psychotherapy: typing.Callable[[], T_Result],
        psychiatric_inpatient: typing.Callable[[], T_Result],
        psychiatric_outpatient: typing.Callable[[], T_Result],
        rehabilitation: typing.Callable[[], T_Result],
        rehabilitation_room_and_board: typing.Callable[[], T_Result],
        rehabilitation_inpatient: typing.Callable[[], T_Result],
        rehabilitation_outpatient: typing.Callable[[], T_Result],
        occupational_therapy: typing.Callable[[], T_Result],
        physical_medicine: typing.Callable[[], T_Result],
        speech_therapy: typing.Callable[[], T_Result],
        skilled_nursing_care: typing.Callable[[], T_Result],
        skilled_nursing_care_room_and_board: typing.Callable[[], T_Result],
        substance_abuse: typing.Callable[[], T_Result],
        alcoholism: typing.Callable[[], T_Result],
        drug_addiction: typing.Callable[[], T_Result],
        vision_optometry: typing.Callable[[], T_Result],
        frames: typing.Callable[[], T_Result],
        routine_exam: typing.Callable[[], T_Result],
        lenses: typing.Callable[[], T_Result],
        nonmedically_necessary_physical: typing.Callable[[], T_Result],
        experimental_drug_therapy: typing.Callable[[], T_Result],
        burn_care: typing.Callable[[], T_Result],
        brand_name_prescription_drug_formulary: typing.Callable[[], T_Result],
        brand_name_prescription_drug_non_formulary: typing.Callable[[], T_Result],
        independent_medical_evaluation: typing.Callable[[], T_Result],
        partial_hospitalization_psychiatric: typing.Callable[[], T_Result],
        day_care_psychiatric: typing.Callable[[], T_Result],
        cognitive_therapy: typing.Callable[[], T_Result],
        massage_therapy: typing.Callable[[], T_Result],
        pulmonary_rehabilitation: typing.Callable[[], T_Result],
        cardiac_rehabilitation: typing.Callable[[], T_Result],
        pediatric: typing.Callable[[], T_Result],
        nursery: typing.Callable[[], T_Result],
        skin: typing.Callable[[], T_Result],
        orthopedic: typing.Callable[[], T_Result],
        cardiac: typing.Callable[[], T_Result],
        lymphatic: typing.Callable[[], T_Result],
        gastrointestinal: typing.Callable[[], T_Result],
        endocrine: typing.Callable[[], T_Result],
        neurology: typing.Callable[[], T_Result],
        eye: typing.Callable[[], T_Result],
        invasive_procedures: typing.Callable[[], T_Result],
        gynecological: typing.Callable[[], T_Result],
        obstetrical: typing.Callable[[], T_Result],
        obstetrical_gynecological: typing.Callable[[], T_Result],
        mail_order_prescription_drug_brand_name: typing.Callable[[], T_Result],
        mail_order_prescription_drug_generic: typing.Callable[[], T_Result],
        physician_visit_office_sick: typing.Callable[[], T_Result],
        physician_visit_office_well: typing.Callable[[], T_Result],
        coronary_care: typing.Callable[[], T_Result],
        private_duty_nursing_inpatient: typing.Callable[[], T_Result],
        private_duty_nursing_home: typing.Callable[[], T_Result],
        surgical_benefits_professional_physician: typing.Callable[[], T_Result],
        surgical_benefits_facility: typing.Callable[[], T_Result],
        mental_health_provider_inpatient: typing.Callable[[], T_Result],
        mental_health_provider_outpatient: typing.Callable[[], T_Result],
        mental_health_facility_inpatient: typing.Callable[[], T_Result],
        mental_health_facility_outpatient: typing.Callable[[], T_Result],
        substance_abuse_facility_inpatient: typing.Callable[[], T_Result],
        substance_abuse_facility_outpatient: typing.Callable[[], T_Result],
        screening_x_ray: typing.Callable[[], T_Result],
        screening_laboratory: typing.Callable[[], T_Result],
        mammogram_high_risk_patient: typing.Callable[[], T_Result],
        mammogram_low_risk_patient: typing.Callable[[], T_Result],
        flu_vaccination: typing.Callable[[], T_Result],
        eyewear_and_eyewear_accessories: typing.Callable[[], T_Result],
        case_management: typing.Callable[[], T_Result],
        dermatology: typing.Callable[[], T_Result],
        durable_medical_equipment: typing.Callable[[], T_Result],
        diabetic_supplies: typing.Callable[[], T_Result],
        generic_prescription_drug_formulary: typing.Callable[[], T_Result],
        generic_prescription_drug_non_formulary: typing.Callable[[], T_Result],
        allergy: typing.Callable[[], T_Result],
        intensive_care: typing.Callable[[], T_Result],
        mental_health: typing.Callable[[], T_Result],
        neonatal_intensive_care: typing.Callable[[], T_Result],
        oncology: typing.Callable[[], T_Result],
        physical_therapy: typing.Callable[[], T_Result],
        pulmonary: typing.Callable[[], T_Result],
        renal: typing.Callable[[], T_Result],
        residential_psychiatric_treatment: typing.Callable[[], T_Result],
        transitional_care: typing.Callable[[], T_Result],
        transitional_nursery_care: typing.Callable[[], T_Result],
        urgent_care: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ServiceTypeCode.MEDICAL_CARE:
            return medical_care()
        if self is ServiceTypeCode.SURGICAL:
            return surgical()
        if self is ServiceTypeCode.CONSULTATION:
            return consultation()
        if self is ServiceTypeCode.DIAGNOSTIC_X_RAY:
            return diagnostic_x_ray()
        if self is ServiceTypeCode.DIAGNOSTIC_LAB:
            return diagnostic_lab()
        if self is ServiceTypeCode.RADIATION_THERAPY:
            return radiation_therapy()
        if self is ServiceTypeCode.ANESTHESIA:
            return anesthesia()
        if self is ServiceTypeCode.SURGICAL_ASSISTANCE:
            return surgical_assistance()
        if self is ServiceTypeCode.OTHER_MEDICAL:
            return other_medical()
        if self is ServiceTypeCode.BLOOD_CHARGES:
            return blood_charges()
        if self is ServiceTypeCode.USED_DURABLE_MEDICAL_EQUIPMENT:
            return used_durable_medical_equipment()
        if self is ServiceTypeCode.DURABLE_MEDICAL_EQUIPMENT_PURCHASE:
            return durable_medical_equipment_purchase()
        if self is ServiceTypeCode.AMBULATORY_SURGICAL_CENTER_FACILITY:
            return ambulatory_surgical_center_facility()
        if self is ServiceTypeCode.RENAL_SUPPLIES_IN_HOME:
            return renal_supplies_in_home()
        if self is ServiceTypeCode.ALTERNATE_METHOD_DIALYSIS:
            return alternate_method_dialysis()
        if self is ServiceTypeCode.CHRONIC_RENAL_DISEASE_EQUIPMENT:
            return chronic_renal_disease_equipment()
        if self is ServiceTypeCode.PRE_ADMISSION_TESTING:
            return pre_admission_testing()
        if self is ServiceTypeCode.DURABLE_MEDICAL_EQUIPMENT_RENTAL:
            return durable_medical_equipment_rental()
        if self is ServiceTypeCode.PNEUMONIA_VACCINE:
            return pneumonia_vaccine()
        if self is ServiceTypeCode.SECOND_SURGICAL_OPINION:
            return second_surgical_opinion()
        if self is ServiceTypeCode.THIRD_SURGICAL_OPINION:
            return third_surgical_opinion()
        if self is ServiceTypeCode.SOCIAL_WORK:
            return social_work()
        if self is ServiceTypeCode.DIAGNOSTIC_DENTAL:
            return diagnostic_dental()
        if self is ServiceTypeCode.PERIODONTICS:
            return periodontics()
        if self is ServiceTypeCode.RESTORATIVE:
            return restorative()
        if self is ServiceTypeCode.ENDODONTICS:
            return endodontics()
        if self is ServiceTypeCode.MAXILLOFACIAL_PROSTHETICS:
            return maxillofacial_prosthetics()
        if self is ServiceTypeCode.ADJUNCTIVE_DENTAL_SERVICES:
            return adjunctive_dental_services()
        if self is ServiceTypeCode.HEALTH_BENEFIT_PLAN_COVERAGE:
            return health_benefit_plan_coverage()
        if self is ServiceTypeCode.PLAN_WAITING_PERIOD:
            return plan_waiting_period()
        if self is ServiceTypeCode.CHIROPRACTIC:
            return chiropractic()
        if self is ServiceTypeCode.CHIROPRACTIC_OFFICE_VISITS:
            return chiropractic_office_visits()
        if self is ServiceTypeCode.DENTAL_CARE:
            return dental_care()
        if self is ServiceTypeCode.DENTAL_CROWNS:
            return dental_crowns()
        if self is ServiceTypeCode.DENTAL_ACCIDENT:
            return dental_accident()
        if self is ServiceTypeCode.ORTHODONTICS:
            return orthodontics()
        if self is ServiceTypeCode.PROSTHODONTICS:
            return prosthodontics()
        if self is ServiceTypeCode.ORAL_SURGERY:
            return oral_surgery()
        if self is ServiceTypeCode.ROUTINE_PREVENTIVE_DENTAL:
            return routine_preventive_dental()
        if self is ServiceTypeCode.HOME_HEALTH_CARE:
            return home_health_care()
        if self is ServiceTypeCode.HOME_HEALTH_PRESCRIPTIONS:
            return home_health_prescriptions()
        if self is ServiceTypeCode.HOME_HEALTH_VISITS:
            return home_health_visits()
        if self is ServiceTypeCode.HOSPICE:
            return hospice()
        if self is ServiceTypeCode.RESPITE_CARE:
            return respite_care()
        if self is ServiceTypeCode.HOSPITAL:
            return hospital()
        if self is ServiceTypeCode.HOSPITAL_INPATIENT:
            return hospital_inpatient()
        if self is ServiceTypeCode.HOSPITAL_ROOM_AND_BOARD:
            return hospital_room_and_board()
        if self is ServiceTypeCode.HOSPITAL_OUTPATIENT:
            return hospital_outpatient()
        if self is ServiceTypeCode.HOSPITAL_EMERGENCY_ACCIDENT:
            return hospital_emergency_accident()
        if self is ServiceTypeCode.HOSPITAL_EMERGENCY_MEDICAL:
            return hospital_emergency_medical()
        if self is ServiceTypeCode.HOSPITAL_AMBULATORY_SURGICAL:
            return hospital_ambulatory_surgical()
        if self is ServiceTypeCode.LONG_TERM_CARE:
            return long_term_care()
        if self is ServiceTypeCode.MAJOR_MEDICAL:
            return major_medical()
        if self is ServiceTypeCode.MEDICALLY_RELATED_TRANSPORTATION:
            return medically_related_transportation()
        if self is ServiceTypeCode.AIR_TRANSPORTATION:
            return air_transportation()
        if self is ServiceTypeCode.CABULANCE:
            return cabulance()
        if self is ServiceTypeCode.LICENSED_AMBULANCE:
            return licensed_ambulance()
        if self is ServiceTypeCode.GENERAL_BENEFITS:
            return general_benefits()
        if self is ServiceTypeCode.IN_VITRO_FERTILIZATION:
            return in_vitro_fertilization()
        if self is ServiceTypeCode.MRICAT_SCAN:
            return mricat_scan()
        if self is ServiceTypeCode.DONOR_PROCEDURES:
            return donor_procedures()
        if self is ServiceTypeCode.ACUPUNCTURE:
            return acupuncture()
        if self is ServiceTypeCode.NEWBORN_CARE:
            return newborn_care()
        if self is ServiceTypeCode.PATHOLOGY:
            return pathology()
        if self is ServiceTypeCode.SMOKING_CESSATION:
            return smoking_cessation()
        if self is ServiceTypeCode.WELL_BABY_CARE:
            return well_baby_care()
        if self is ServiceTypeCode.MATERNITY:
            return maternity()
        if self is ServiceTypeCode.TRANSPLANTS:
            return transplants()
        if self is ServiceTypeCode.AUDIOLOGY_EXAM:
            return audiology_exam()
        if self is ServiceTypeCode.INHALATION_THERAPY:
            return inhalation_therapy()
        if self is ServiceTypeCode.DIAGNOSTIC_MEDICAL:
            return diagnostic_medical()
        if self is ServiceTypeCode.PRIVATE_DUTY_NURSING:
            return private_duty_nursing()
        if self is ServiceTypeCode.PROSTHETIC_DEVICE:
            return prosthetic_device()
        if self is ServiceTypeCode.DIALYSIS:
            return dialysis()
        if self is ServiceTypeCode.OTOLOGICAL_EXAM:
            return otological_exam()
        if self is ServiceTypeCode.CHEMOTHERAPY:
            return chemotherapy()
        if self is ServiceTypeCode.ALLERGY_TESTING:
            return allergy_testing()
        if self is ServiceTypeCode.IMMUNIZATIONS:
            return immunizations()
        if self is ServiceTypeCode.ROUTINE_PHYSICAL:
            return routine_physical()
        if self is ServiceTypeCode.FAMILY_PLANNING:
            return family_planning()
        if self is ServiceTypeCode.INFERTILITY:
            return infertility()
        if self is ServiceTypeCode.ABORTION:
            return abortion()
        if self is ServiceTypeCode.AIDS:
            return aids()
        if self is ServiceTypeCode.EMERGENCY_SERVICES:
            return emergency_services()
        if self is ServiceTypeCode.CANCER:
            return cancer()
        if self is ServiceTypeCode.PHARMACY:
            return pharmacy()
        if self is ServiceTypeCode.FREE_STANDING_PRESCRIPTION_DRUG:
            return free_standing_prescription_drug()
        if self is ServiceTypeCode.MAIL_ORDER_PRESCRIPTION_DRUG:
            return mail_order_prescription_drug()
        if self is ServiceTypeCode.BRAND_NAME_PRESCRIPTION_DRUG:
            return brand_name_prescription_drug()
        if self is ServiceTypeCode.GENERIC_PRESCRIPTION_DRUG:
            return generic_prescription_drug()
        if self is ServiceTypeCode.PODIATRY:
            return podiatry()
        if self is ServiceTypeCode.PODIATRY_OFFICE_VISITS:
            return podiatry_office_visits()
        if self is ServiceTypeCode.PODIATRY_NURSING_HOME_VISITS:
            return podiatry_nursing_home_visits()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN:
            return professional_physician()
        if self is ServiceTypeCode.ANESTHESIOLOGIST:
            return anesthesiologist()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_OFFICE:
            return professional_physician_visit_office()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_INPATIENT:
            return professional_physician_visit_inpatient()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_OUTPATIENT:
            return professional_physician_visit_outpatient()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_NURSING_HOME:
            return professional_physician_visit_nursing_home()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_SKILLED_NURSING_FACILITY:
            return professional_physician_visit_skilled_nursing_facility()
        if self is ServiceTypeCode.PROFESSIONAL_PHYSICIAN_VISIT_HOME:
            return professional_physician_visit_home()
        if self is ServiceTypeCode.PSYCHIATRIC:
            return psychiatric()
        if self is ServiceTypeCode.PSYCHIATRIC_ROOM_AND_BOARD:
            return psychiatric_room_and_board()
        if self is ServiceTypeCode.PSYCHOTHERAPY:
            return psychotherapy()
        if self is ServiceTypeCode.PSYCHIATRIC_INPATIENT:
            return psychiatric_inpatient()
        if self is ServiceTypeCode.PSYCHIATRIC_OUTPATIENT:
            return psychiatric_outpatient()
        if self is ServiceTypeCode.REHABILITATION:
            return rehabilitation()
        if self is ServiceTypeCode.REHABILITATION_ROOM_AND_BOARD:
            return rehabilitation_room_and_board()
        if self is ServiceTypeCode.REHABILITATION_INPATIENT:
            return rehabilitation_inpatient()
        if self is ServiceTypeCode.REHABILITATION_OUTPATIENT:
            return rehabilitation_outpatient()
        if self is ServiceTypeCode.OCCUPATIONAL_THERAPY:
            return occupational_therapy()
        if self is ServiceTypeCode.PHYSICAL_MEDICINE:
            return physical_medicine()
        if self is ServiceTypeCode.SPEECH_THERAPY:
            return speech_therapy()
        if self is ServiceTypeCode.SKILLED_NURSING_CARE:
            return skilled_nursing_care()
        if self is ServiceTypeCode.SKILLED_NURSING_CARE_ROOM_AND_BOARD:
            return skilled_nursing_care_room_and_board()
        if self is ServiceTypeCode.SUBSTANCE_ABUSE:
            return substance_abuse()
        if self is ServiceTypeCode.ALCOHOLISM:
            return alcoholism()
        if self is ServiceTypeCode.DRUG_ADDICTION:
            return drug_addiction()
        if self is ServiceTypeCode.VISION_OPTOMETRY:
            return vision_optometry()
        if self is ServiceTypeCode.FRAMES:
            return frames()
        if self is ServiceTypeCode.ROUTINE_EXAM:
            return routine_exam()
        if self is ServiceTypeCode.LENSES:
            return lenses()
        if self is ServiceTypeCode.NONMEDICALLY_NECESSARY_PHYSICAL:
            return nonmedically_necessary_physical()
        if self is ServiceTypeCode.EXPERIMENTAL_DRUG_THERAPY:
            return experimental_drug_therapy()
        if self is ServiceTypeCode.BURN_CARE:
            return burn_care()
        if self is ServiceTypeCode.BRAND_NAME_PRESCRIPTION_DRUG_FORMULARY:
            return brand_name_prescription_drug_formulary()
        if self is ServiceTypeCode.BRAND_NAME_PRESCRIPTION_DRUG_NON_FORMULARY:
            return brand_name_prescription_drug_non_formulary()
        if self is ServiceTypeCode.INDEPENDENT_MEDICAL_EVALUATION:
            return independent_medical_evaluation()
        if self is ServiceTypeCode.PARTIAL_HOSPITALIZATION_PSYCHIATRIC:
            return partial_hospitalization_psychiatric()
        if self is ServiceTypeCode.DAY_CARE_PSYCHIATRIC:
            return day_care_psychiatric()
        if self is ServiceTypeCode.COGNITIVE_THERAPY:
            return cognitive_therapy()
        if self is ServiceTypeCode.MASSAGE_THERAPY:
            return massage_therapy()
        if self is ServiceTypeCode.PULMONARY_REHABILITATION:
            return pulmonary_rehabilitation()
        if self is ServiceTypeCode.CARDIAC_REHABILITATION:
            return cardiac_rehabilitation()
        if self is ServiceTypeCode.PEDIATRIC:
            return pediatric()
        if self is ServiceTypeCode.NURSERY:
            return nursery()
        if self is ServiceTypeCode.SKIN:
            return skin()
        if self is ServiceTypeCode.ORTHOPEDIC:
            return orthopedic()
        if self is ServiceTypeCode.CARDIAC:
            return cardiac()
        if self is ServiceTypeCode.LYMPHATIC:
            return lymphatic()
        if self is ServiceTypeCode.GASTROINTESTINAL:
            return gastrointestinal()
        if self is ServiceTypeCode.ENDOCRINE:
            return endocrine()
        if self is ServiceTypeCode.NEUROLOGY:
            return neurology()
        if self is ServiceTypeCode.EYE:
            return eye()
        if self is ServiceTypeCode.INVASIVE_PROCEDURES:
            return invasive_procedures()
        if self is ServiceTypeCode.GYNECOLOGICAL:
            return gynecological()
        if self is ServiceTypeCode.OBSTETRICAL:
            return obstetrical()
        if self is ServiceTypeCode.OBSTETRICAL_GYNECOLOGICAL:
            return obstetrical_gynecological()
        if self is ServiceTypeCode.MAIL_ORDER_PRESCRIPTION_DRUG_BRAND_NAME:
            return mail_order_prescription_drug_brand_name()
        if self is ServiceTypeCode.MAIL_ORDER_PRESCRIPTION_DRUG_GENERIC:
            return mail_order_prescription_drug_generic()
        if self is ServiceTypeCode.PHYSICIAN_VISIT_OFFICE_SICK:
            return physician_visit_office_sick()
        if self is ServiceTypeCode.PHYSICIAN_VISIT_OFFICE_WELL:
            return physician_visit_office_well()
        if self is ServiceTypeCode.CORONARY_CARE:
            return coronary_care()
        if self is ServiceTypeCode.PRIVATE_DUTY_NURSING_INPATIENT:
            return private_duty_nursing_inpatient()
        if self is ServiceTypeCode.PRIVATE_DUTY_NURSING_HOME:
            return private_duty_nursing_home()
        if self is ServiceTypeCode.SURGICAL_BENEFITS_PROFESSIONAL_PHYSICIAN:
            return surgical_benefits_professional_physician()
        if self is ServiceTypeCode.SURGICAL_BENEFITS_FACILITY:
            return surgical_benefits_facility()
        if self is ServiceTypeCode.MENTAL_HEALTH_PROVIDER_INPATIENT:
            return mental_health_provider_inpatient()
        if self is ServiceTypeCode.MENTAL_HEALTH_PROVIDER_OUTPATIENT:
            return mental_health_provider_outpatient()
        if self is ServiceTypeCode.MENTAL_HEALTH_FACILITY_INPATIENT:
            return mental_health_facility_inpatient()
        if self is ServiceTypeCode.MENTAL_HEALTH_FACILITY_OUTPATIENT:
            return mental_health_facility_outpatient()
        if self is ServiceTypeCode.SUBSTANCE_ABUSE_FACILITY_INPATIENT:
            return substance_abuse_facility_inpatient()
        if self is ServiceTypeCode.SUBSTANCE_ABUSE_FACILITY_OUTPATIENT:
            return substance_abuse_facility_outpatient()
        if self is ServiceTypeCode.SCREENING_X_RAY:
            return screening_x_ray()
        if self is ServiceTypeCode.SCREENING_LABORATORY:
            return screening_laboratory()
        if self is ServiceTypeCode.MAMMOGRAM_HIGH_RISK_PATIENT:
            return mammogram_high_risk_patient()
        if self is ServiceTypeCode.MAMMOGRAM_LOW_RISK_PATIENT:
            return mammogram_low_risk_patient()
        if self is ServiceTypeCode.FLU_VACCINATION:
            return flu_vaccination()
        if self is ServiceTypeCode.EYEWEAR_AND_EYEWEAR_ACCESSORIES:
            return eyewear_and_eyewear_accessories()
        if self is ServiceTypeCode.CASE_MANAGEMENT:
            return case_management()
        if self is ServiceTypeCode.DERMATOLOGY:
            return dermatology()
        if self is ServiceTypeCode.DURABLE_MEDICAL_EQUIPMENT:
            return durable_medical_equipment()
        if self is ServiceTypeCode.DIABETIC_SUPPLIES:
            return diabetic_supplies()
        if self is ServiceTypeCode.GENERIC_PRESCRIPTION_DRUG_FORMULARY:
            return generic_prescription_drug_formulary()
        if self is ServiceTypeCode.GENERIC_PRESCRIPTION_DRUG_NON_FORMULARY:
            return generic_prescription_drug_non_formulary()
        if self is ServiceTypeCode.ALLERGY:
            return allergy()
        if self is ServiceTypeCode.INTENSIVE_CARE:
            return intensive_care()
        if self is ServiceTypeCode.MENTAL_HEALTH:
            return mental_health()
        if self is ServiceTypeCode.NEONATAL_INTENSIVE_CARE:
            return neonatal_intensive_care()
        if self is ServiceTypeCode.ONCOLOGY:
            return oncology()
        if self is ServiceTypeCode.PHYSICAL_THERAPY:
            return physical_therapy()
        if self is ServiceTypeCode.PULMONARY:
            return pulmonary()
        if self is ServiceTypeCode.RENAL:
            return renal()
        if self is ServiceTypeCode.RESIDENTIAL_PSYCHIATRIC_TREATMENT:
            return residential_psychiatric_treatment()
        if self is ServiceTypeCode.TRANSITIONAL_CARE:
            return transitional_care()
        if self is ServiceTypeCode.TRANSITIONAL_NURSERY_CARE:
            return transitional_nursery_care()
        if self is ServiceTypeCode.URGENT_CARE:
            return urgent_care()



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ClaimAdjudication,
    ClaimAdjudicationCreate,
    InsuranceAdjudication,
    InsuranceAdjudicationCreate,
    InsuranceAdjudicationId,
    ServiceLineAdjudication,
    ServiceLineAdjudicationCreate,
    ServiceLineAdjudicationId,
)

__all__ = [
    "ClaimAdjudication",
    "ClaimAdjudicationCreate",
    "InsuranceAdjudication",
    "InsuranceAdjudicationCreate",
    "InsuranceAdjudicationId",
    "ServiceLineAdjudication",
    "ServiceLineAdjudicationCreate",
    "ServiceLineAdjudicationId",
]



# This file was auto-generated by Fern from our API Definition.

from .types import InsuranceCard, InsuranceCardBase, InsuranceCardCreate, InsuranceCardId

__all__ = ["InsuranceCard", "InsuranceCardBase", "InsuranceCardCreate", "InsuranceCardId"]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.resource_page import ResourcePage
from .organization_provider_v_2 import OrganizationProviderV2


class OrganizationProviderPageV2(ResourcePage):
    """
    Examples
    --------
    import datetime
    import uuid

    from candid import (
        Identifier,
        IdentifierCode,
        IdentifierValue_MedicareProviderIdentifier,
        State,
    )
    from candid.resources.organization_providers.v_2 import (
        LicenseType,
        ProviderType,
    )
    from candid.resources.organization_providers.v_3 import (
        OrganizationProviderPageV2,
        OrganizationProviderV2,
    )

    OrganizationProviderPageV2(
        items=[
            OrganizationProviderV2(
                npi="1234567890",
                is_rendering=True,
                is_billing=True,
                first_name="John",
                last_name="Doe",
                organization_name="Acme Medical",
                provider_type=ProviderType.INDIVIDUAL,
                tax_id="123456789",
                taxonomy_code="1234567890",
                license_type=LicenseType.MD,
                employment_start_date=datetime.date.fromisoformat(
                    "2020-10-07",
                ),
                employment_termination_date=datetime.date.fromisoformat(
                    "2021-10-07",
                ),
                organization_provider_id=uuid.UUID(
                    "965a563a-0285-4910-9569-e3739c0f6eab",
                ),
                qualifications=[
                    Identifier(
                        identifier_id=uuid.UUID(
                            "123e4567-e89b-12d3-a456-426614174000",
                        ),
                        identifier_code=IdentifierCode.MCR,
                        identifier_value=IdentifierValue_MedicareProviderIdentifier(
                            state=State.CA,
                            provider_number="1234567890",
                        ),
                    )
                ],
            )
        ],
    )
    """

    items: typing.List[OrganizationProviderV2]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from ..types.schema_validation_failure import SchemaValidationFailure


class SchemaValidationHttpFailure(ApiError):
    def __init__(self, body: SchemaValidationFailure):
        super().__init__(status_code=422, body=body)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ........core.datetime_utils import serialize_datetime
from ........core.pydantic_utilities import deep_union_pydantic_dicts
from .....common.types.patient_id import PatientId
from .....common.types.relationship import Relationship
from .coverage_benefits import CoverageBenefits
from .coverage_status import CoverageStatus
from .eligibility_check_metadata import EligibilityCheckMetadata
from .insurance_plan import InsurancePlan
from .subscriber import Subscriber


class MutableCoverage(pydantic.BaseModel):
    status: CoverageStatus = pydantic.Field()
    """
    The status indiciating if the coverage is active or not.
    """

    subscriber: Subscriber = pydantic.Field()
    """
    The party who has signed-up for or 'owns' the contractual relationship to the policy or to whom the benefit of the policy for services rendered to them or their family is due.
    """

    relationship: Relationship = pydantic.Field()
    """
    The relationship of beneficiary (patient) to the subscriber. https://hl7.org/fhir/valueset-relationship.html
    """

    patient: PatientId = pydantic.Field()
    """
    The patient who benefits from the insurance coverage
    """

    insurance_plan: InsurancePlan
    verified: bool = pydantic.Field()
    """
    A boolean indicating if the coverage has been verified by a user.
    """

    eligibility_checks: typing.Optional[typing.List[EligibilityCheckMetadata]] = pydantic.Field(default=None)
    """
    A list of eligibility check metadata that have been initiated on this coverage.
    """

    benefits: typing.Optional[CoverageBenefits] = pydantic.Field(default=None)
    """
    The eligibility of the patient for the coverage, manually verified by users.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ThirdPartyPayerPayment,
    ThirdPartyPayerPaymentCreate,
    ThirdPartyPayerPaymentId,
    ThirdPartyPayerPaymentSortField,
    ThirdPartyPayerPaymentsPage,
)

__all__ = [
    "ThirdPartyPayerPayment",
    "ThirdPartyPayerPaymentCreate",
    "ThirdPartyPayerPaymentId",
    "ThirdPartyPayerPaymentSortField",
    "ThirdPartyPayerPaymentsPage",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class SexualOrientation(str, enum.Enum):
    HETEROSEXUAL = "HETEROSEXUAL"
    HOMOSEXUAL = "HOMOSEXUAL"
    BISEXUAL = "BISEXUAL"
    TWO_SPIRIT = "TWO_SPIRIT"
    OTHER = "OTHER"
    UNKNOWN = "UNKNOWN"
    REFUSED = "REFUSED"

    def visit(
        self,
        heterosexual: typing.Callable[[], T_Result],
        homosexual: typing.Callable[[], T_Result],
        bisexual: typing.Callable[[], T_Result],
        two_spirit: typing.Callable[[], T_Result],
        other: typing.Callable[[], T_Result],
        unknown: typing.Callable[[], T_Result],
        refused: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is SexualOrientation.HETEROSEXUAL:
            return heterosexual()
        if self is SexualOrientation.HOMOSEXUAL:
            return homosexual()
        if self is SexualOrientation.BISEXUAL:
            return bisexual()
        if self is SexualOrientation.TWO_SPIRIT:
            return two_spirit()
        if self is SexualOrientation.OTHER:
            return other()
        if self is SexualOrientation.UNKNOWN:
            return unknown()
        if self is SexualOrientation.REFUSED:
            return refused()



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....organization_providers.resources.v_2.types.organization_provider_id import OrganizationProviderId
from .....payers.resources.v_3.types.payer_uuid import PayerUuid
from .explanation import Explanation


class ComputeAllInNetworkRenderingProvidersResult_RenderingProviders(pydantic.BaseModel):
    rendering_providers: typing.List[OrganizationProviderId]
    routed_payer_uuid: PayerUuid
    routed_billing_provider_id: OrganizationProviderId
    type: typing.Literal["rendering_providers"] = "rendering_providers"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class ComputeAllInNetworkRenderingProvidersResult_Indeterminate(pydantic.BaseModel):
    error: str
    explanation: Explanation
    routed_payer_uuid: typing.Optional[PayerUuid] = None
    routed_billing_provider_id: typing.Optional[OrganizationProviderId] = None
    type: typing.Literal["indeterminate"] = "indeterminate"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class ComputeAllInNetworkRenderingProvidersResult_OutOfNetwork(pydantic.BaseModel):
    explanation: Explanation
    routed_payer_uuid: PayerUuid
    routed_billing_provider_id: OrganizationProviderId
    type: typing.Literal["out_of_network"] = "out_of_network"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


ComputeAllInNetworkRenderingProvidersResult = typing.Union[
    ComputeAllInNetworkRenderingProvidersResult_RenderingProviders,
    ComputeAllInNetworkRenderingProvidersResult_Indeterminate,
    ComputeAllInNetworkRenderingProvidersResult_OutOfNetwork,
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentWorkQueue(str, enum.Enum):
    EMERGENT_ISSUE = "EMERGENT_ISSUE"
    NEW_PATIENT = "NEW_PATIENT"
    RETURNING_PATIENT = "RETURNING_PATIENT"

    def visit(
        self,
        emergent_issue: typing.Callable[[], T_Result],
        new_patient: typing.Callable[[], T_Result],
        returning_patient: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentWorkQueue.EMERGENT_ISSUE:
            return emergent_issue()
        if self is AppointmentWorkQueue.NEW_PATIENT:
            return new_patient()
        if self is AppointmentWorkQueue.RETURNING_PATIENT:
            return returning_patient()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.invoice_id import InvoiceId
from .....commons.types.patient_external_id import PatientExternalId
from .....invoices.resources.v_2.types.invoice_item_info import InvoiceItemInfo
from .....invoices.resources.v_2.types.invoice_status import InvoiceStatus


class ImportInvoice(pydantic.BaseModel):
    id: InvoiceId
    created_at: dt.datetime
    updated_at: dt.datetime
    items: InvoiceItemInfo = pydantic.Field()
    """
    The InvoiceItem rollup which contains all claim and service line invoice items
    """

    patient_external_id: PatientExternalId
    external_customer_identifier: str = pydantic.Field()
    """
    Id of the customer in the source system
    """

    status: InvoiceStatus
    external_identifier: str = pydantic.Field()
    """
    Id of the invoice being imported in the source system
    """

    note: typing.Optional[str] = None
    customer_invoice_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    Link to the patient view of the invoice in the third-party service
    """

    due_date: dt.date
    amount_cents: int = pydantic.Field()
    """
    Total monetary amount (in cents) of all Invoice Items
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .create_non_insurance_payer_request import CreateNonInsurancePayerRequest
from .non_insurance_payer import NonInsurancePayer
from .non_insurance_payer_category_update import (
    NonInsurancePayerCategoryUpdate,
    NonInsurancePayerCategoryUpdate_Remove,
    NonInsurancePayerCategoryUpdate_Set,
)
from .non_insurance_payer_description_update import (
    NonInsurancePayerDescriptionUpdate,
    NonInsurancePayerDescriptionUpdate_Remove,
    NonInsurancePayerDescriptionUpdate_Set,
)
from .non_insurance_payer_id import NonInsurancePayerId
from .non_insurance_payer_page import NonInsurancePayerPage
from .non_insurance_payer_sort_field import NonInsurancePayerSortField
from .non_insurance_payer_update_request import NonInsurancePayerUpdateRequest
from .toggle_non_insurance_payer_enablement_request import ToggleNonInsurancePayerEnablementRequest

__all__ = [
    "CreateNonInsurancePayerRequest",
    "NonInsurancePayer",
    "NonInsurancePayerCategoryUpdate",
    "NonInsurancePayerCategoryUpdate_Remove",
    "NonInsurancePayerCategoryUpdate_Set",
    "NonInsurancePayerDescriptionUpdate",
    "NonInsurancePayerDescriptionUpdate_Remove",
    "NonInsurancePayerDescriptionUpdate_Set",
    "NonInsurancePayerId",
    "NonInsurancePayerPage",
    "NonInsurancePayerSortField",
    "NonInsurancePayerUpdateRequest",
    "ToggleNonInsurancePayerEnablementRequest",
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .match_cpt_code import MatchCptCode
from .match_date import MatchDate
from .match_facility_type_code import MatchFacilityTypeCode
from .match_geo import MatchGeo
from .match_license_type import MatchLicenseType
from .match_modifiers import MatchModifiers
from .match_network_types import MatchNetworkTypes
from .match_payer import MatchPayer
from .match_provider import MatchProvider


class DimensionMatch(pydantic.BaseModel):
    """
    Dimension matching for a service line
    """

    payer: MatchPayer
    geography: MatchGeo
    organization_billing_provider: MatchProvider
    date_of_service: MatchDate
    cpt_code: MatchCptCode
    modifiers: MatchModifiers
    license_type: MatchLicenseType
    facility_type_code: MatchFacilityTypeCode
    network_types: MatchNetworkTypes

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .resources.v_4.client import AsyncV4Client, V4Client


class PatientPaymentsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.v_4 = V4Client(client_wrapper=self._client_wrapper)


class AsyncPatientPaymentsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.v_4 = AsyncV4Client(client_wrapper=self._client_wrapper)



# This file was auto-generated by Fern from our API Definition.

from .types import (
    ThirdPartyPayerRefund,
    ThirdPartyPayerRefundCreate,
    ThirdPartyPayerRefundId,
    ThirdPartyPayerRefundSortField,
    ThirdPartyPayerRefundsPage,
)

__all__ = [
    "ThirdPartyPayerRefund",
    "ThirdPartyPayerRefundCreate",
    "ThirdPartyPayerRefundId",
    "ThirdPartyPayerRefundSortField",
    "ThirdPartyPayerRefundsPage",
]



# This file was auto-generated by Fern from our API Definition.

from .encounter_has_existing_guarantor_error_type import EncounterHasExistingGuarantorErrorType
from .guarantor import Guarantor
from .guarantor_base import GuarantorBase
from .guarantor_create import GuarantorCreate
from .guarantor_id import GuarantorId

__all__ = ["EncounterHasExistingGuarantorErrorType", "Guarantor", "GuarantorBase", "GuarantorCreate", "GuarantorId"]



# This file was auto-generated by Fern from our API Definition.

from .dimension_match import DimensionMatch
from .dimension_name import DimensionName
from .dimensions import Dimensions
from .dimensions_page import DimensionsPage
from .match_cpt_code import MatchCptCode
from .match_date import MatchDate
from .match_facility_type_code import MatchFacilityTypeCode
from .match_geo import MatchGeo
from .match_license_type import MatchLicenseType
from .match_modifiers import MatchModifiers
from .match_network_types import MatchNetworkTypes
from .match_payer import MatchPayer
from .match_provider import MatchProvider
from .match_result import MatchResult
from .match_test_result import MatchTestResult
from .new_rate import NewRate
from .new_rate_version import NewRateVersion
from .optional_dimensions import OptionalDimensions
from .overlapping_rate_entries_error import OverlappingRateEntriesError
from .payer_threshold import PayerThreshold
from .payer_thresholds_page import PayerThresholdsPage
from .rate import Rate
from .rate_entry import RateEntry
from .rate_upload import RateUpload, RateUpload_NewRate, RateUpload_NewVersion
from .rate_upload_with_possible_errors import RateUploadWithPossibleErrors
from .rates_page import RatesPage
from .threshold_match import ThresholdMatch
from .validation_error import (
    ValidationError,
    ValidationError_DuplicateRate,
    ValidationError_EmptyEntries,
    ValidationError_OrganizationProviderNotFound,
    ValidationError_OverlappingRateEntries,
    ValidationError_VersionConflict,
)

__all__ = [
    "DimensionMatch",
    "DimensionName",
    "Dimensions",
    "DimensionsPage",
    "MatchCptCode",
    "MatchDate",
    "MatchFacilityTypeCode",
    "MatchGeo",
    "MatchLicenseType",
    "MatchModifiers",
    "MatchNetworkTypes",
    "MatchPayer",
    "MatchProvider",
    "MatchResult",
    "MatchTestResult",
    "NewRate",
    "NewRateVersion",
    "OptionalDimensions",
    "OverlappingRateEntriesError",
    "PayerThreshold",
    "PayerThresholdsPage",
    "Rate",
    "RateEntry",
    "RateUpload",
    "RateUploadWithPossibleErrors",
    "RateUpload_NewRate",
    "RateUpload_NewVersion",
    "RatesPage",
    "ThresholdMatch",
    "ValidationError",
    "ValidationError_DuplicateRate",
    "ValidationError_EmptyEntries",
    "ValidationError_OrganizationProviderNotFound",
    "ValidationError_OverlappingRateEntries",
    "ValidationError_VersionConflict",
]



# This file was auto-generated by Fern from our API Definition.

from .types import AppointmentListItem, AppointmentListPage, FilterQueryString, PatientListItem, PatientListPage

__all__ = ["AppointmentListItem", "AppointmentListPage", "FilterQueryString", "PatientListItem", "PatientListPage"]



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.pydantic_utilities import pydantic_v1
from .....core.request_options import RequestOptions
from ....commons.types.page_token import PageToken
from .types.external_payment_account_config_page import ExternalPaymentAccountConfigPage


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> ExternalPaymentAccountConfigPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExternalPaymentAccountConfigPage

        Examples
        --------
        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.external_payment_account_config.v_1.get_multi(
            limit=1,
            page_token="eyJ0b2tlbiI6IjEiLCJwYWdlX3Rva2VuIjoiMiJ9",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/external-payment-account-config/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={"limit": limit, "page_token": page_token},
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ExternalPaymentAccountConfigPage, _response_json)  # type: ignore
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_multi(
        self,
        *,
        limit: typing.Optional[int] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None
    ) -> ExternalPaymentAccountConfigPage:
        """
        Parameters
        ----------
        limit : typing.Optional[int]
            Defaults to 100

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExternalPaymentAccountConfigPage

        Examples
        --------
        import asyncio

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.external_payment_account_config.v_1.get_multi(
                limit=1,
                page_token="eyJ0b2tlbiI6IjEiLCJwYWdlX3Rva2VuIjoiMiJ9",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/external-payment-account-config/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={"limit": limit, "page_token": page_token},
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ExternalPaymentAccountConfigPage, _response_json)  # type: ignore
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts


class Vitals(pydantic.BaseModel):
    """
    Examples
    --------
    from candid.resources.encounters.v_4 import Vitals

    Vitals(
        height_in=70,
        weight_lbs=165,
        blood_pressure_systolic_mmhg=115,
        blood_pressure_diastolic_mmhg=85,
        body_temperature_f=98.0,
        hemoglobin_gdl=15.1,
        hematocrit_pct=51.2,
    )
    """

    height_in: typing.Optional[int] = None
    weight_lbs: typing.Optional[int] = None
    blood_pressure_systolic_mmhg: typing.Optional[int] = None
    blood_pressure_diastolic_mmhg: typing.Optional[int] = None
    body_temperature_f: typing.Optional[float] = None
    hemoglobin_gdl: typing.Optional[float] = None
    hematocrit_pct: typing.Optional[float] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from ...commons.types.date_range_optional_end import DateRangeOptionalEnd
from ...commons.types.removable_date_range_optional_end import RemovableDateRangeOptionalEnd
from .identifier_code import IdentifierCode
from .identifier_id import IdentifierId
from .identifier_value import IdentifierValue


class UpdatableIdentifier_Add(pydantic.BaseModel):
    period: typing.Optional[DateRangeOptionalEnd] = None
    identifier_code: IdentifierCode
    identifier_value: IdentifierValue
    type: typing.Literal["add"] = "add"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class UpdatableIdentifier_Update(pydantic.BaseModel):
    identifier_id: IdentifierId
    identifier_code: typing.Optional[IdentifierCode] = None
    identifier_value: typing.Optional[IdentifierValue] = None
    period: typing.Optional[RemovableDateRangeOptionalEnd] = None
    type: typing.Literal["update"] = "update"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class UpdatableIdentifier_Remove(pydantic.BaseModel):
    value: IdentifierId
    type: typing.Literal["remove"] = "remove"

    class Config:
        frozen = True
        smart_union = True


UpdatableIdentifier = typing.Union[UpdatableIdentifier_Add, UpdatableIdentifier_Update, UpdatableIdentifier_Remove]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PatientPaymentSource(str, enum.Enum):
    MANUAL_ENTRY = "MANUAL_ENTRY"
    CHARGEBEE_PAYMENTS = "CHARGEBEE_PAYMENTS"
    CHARGEBEE_MANUALLY_VOIDED_BY_CANDID = "CHARGEBEE MANUALLY VOIDED BY CANDID"
    CHARGEBEE_REFUNDS = "CHARGEBEE_REFUNDS"
    SQUARE_REFUNDS = "SQUARE_REFUNDS"
    SQUARE_PAYMENTS = "SQUARE_PAYMENTS"
    STRIPE_CHARGES = "STRIPE_CHARGES"
    STRIPE_REFUNDS = "STRIPE_REFUNDS"
    ELATION_PAYMENTS = "ELATION_PAYMENTS"

    def visit(
        self,
        manual_entry: typing.Callable[[], T_Result],
        chargebee_payments: typing.Callable[[], T_Result],
        chargebee_manually_voided_by_candid: typing.Callable[[], T_Result],
        chargebee_refunds: typing.Callable[[], T_Result],
        square_refunds: typing.Callable[[], T_Result],
        square_payments: typing.Callable[[], T_Result],
        stripe_charges: typing.Callable[[], T_Result],
        stripe_refunds: typing.Callable[[], T_Result],
        elation_payments: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is PatientPaymentSource.MANUAL_ENTRY:
            return manual_entry()
        if self is PatientPaymentSource.CHARGEBEE_PAYMENTS:
            return chargebee_payments()
        if self is PatientPaymentSource.CHARGEBEE_MANUALLY_VOIDED_BY_CANDID:
            return chargebee_manually_voided_by_candid()
        if self is PatientPaymentSource.CHARGEBEE_REFUNDS:
            return chargebee_refunds()
        if self is PatientPaymentSource.SQUARE_REFUNDS:
            return square_refunds()
        if self is PatientPaymentSource.SQUARE_PAYMENTS:
            return square_payments()
        if self is PatientPaymentSource.STRIPE_CHARGES:
            return stripe_charges()
        if self is PatientPaymentSource.STRIPE_REFUNDS:
            return stripe_refunds()
        if self is PatientPaymentSource.ELATION_PAYMENTS:
            return elation_payments()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class Primitive(str, enum.Enum):
    """
    The BOOLEAN and STRING primitives respectively map to the `boolean` and `string` JSON data types.
    The DOUBLE and INTEGER primitives must be written as a JSON `number` type.
    """

    BOOLEAN = "BOOLEAN"
    DOUBLE = "DOUBLE"
    INTEGER = "INTEGER"
    STRING = "STRING"

    def visit(
        self,
        boolean: typing.Callable[[], T_Result],
        double: typing.Callable[[], T_Result],
        integer: typing.Callable[[], T_Result],
        string: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is Primitive.BOOLEAN:
            return boolean()
        if self is Primitive.DOUBLE:
            return double()
        if self is Primitive.INTEGER:
            return integer()
        if self is Primitive.STRING:
            return string()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.jsonable_encoder import jsonable_encoder
from .....core.pydantic_utilities import pydantic_v1
from .....core.request_options import RequestOptions
from ....commons.errors.entity_conflict_error import EntityConflictError
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.unprocessable_entity_error import UnprocessableEntityError
from ....commons.types.encounter_external_id import EncounterExternalId
from ....commons.types.entity_conflict_error_message import EntityConflictErrorMessage
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.invoice_id import InvoiceId
from ....commons.types.page_token import PageToken
from ....commons.types.patient_external_id import PatientExternalId
from ....commons.types.sort_direction import SortDirection
from ....commons.types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage
from ....invoices.resources.v_2.types.invoice_sort_field import InvoiceSortField
from ....invoices.resources.v_2.types.invoice_status import InvoiceStatus
from .types.create_import_invoice_request import CreateImportInvoiceRequest
from .types.import_invoice import ImportInvoice
from .types.import_invoice_update_request import ImportInvoiceUpdateRequest
from .types.import_invoices_page import ImportInvoicesPage

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def import_invoice(
        self, *, request: CreateImportInvoiceRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> ImportInvoice:
        """
        Import an existing invoice from a third party service to reflect state in Candid.

        Parameters
        ----------
        request : CreateImportInvoiceRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import datetime
        import uuid

        from candid.client import CandidApiClient
        from candid.resources.import_invoice.v_1 import CreateImportInvoiceRequest
        from candid.resources.invoices.v_2 import (
            InvoiceItemAttributionCreate_ServiceLineId,
            InvoiceItemCreate,
            InvoiceStatus,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.import_invoice.v_1.import_invoice(
            request=CreateImportInvoiceRequest(
                external_payment_account_config_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                patient_external_id="string",
                external_customer_identifier="string",
                note="string",
                due_date=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                items=[
                    InvoiceItemCreate(
                        attribution=InvoiceItemAttributionCreate_ServiceLineId(
                            value=uuid.UUID(
                                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                            )
                        ),
                        amount_cents=1,
                    )
                ],
                status=InvoiceStatus.DRAFT,
                external_identifier="string",
                customer_invoice_url="string",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_multi(
        self,
        *,
        patient_external_id: typing.Optional[PatientExternalId] = None,
        encounter_external_id: typing.Optional[EncounterExternalId] = None,
        note: typing.Optional[str] = None,
        due_date_before: typing.Optional[dt.date] = None,
        due_date_after: typing.Optional[dt.date] = None,
        status: typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]] = None,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[InvoiceSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImportInvoicesPage:
        """
        Returns all Invoices for the authenticated user's organziation with all filters applied.

        Parameters
        ----------
        patient_external_id : typing.Optional[PatientExternalId]

        encounter_external_id : typing.Optional[EncounterExternalId]

        note : typing.Optional[str]
            partial match supported

        due_date_before : typing.Optional[dt.date]
            all invoices whose due date is before this due date, not inclusive

        due_date_after : typing.Optional[dt.date]
            all invoices whose due date is after this due date, not inclusive

        status : typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]]
            all invoices that match any of the provided statuses

        limit : typing.Optional[int]
            Defaults to 100

        sort : typing.Optional[InvoiceSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoicesPage

        Examples
        --------
        import datetime

        from candid import SortDirection
        from candid.client import CandidApiClient
        from candid.resources.invoices.v_2 import InvoiceSortField, InvoiceStatus

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.import_invoice.v_1.get_multi(
            patient_external_id="string",
            encounter_external_id="string",
            note="string",
            due_date_before=datetime.date.fromisoformat(
                "2023-01-15",
            ),
            due_date_after=datetime.date.fromisoformat(
                "2023-01-15",
            ),
            status=InvoiceStatus.DRAFT,
            limit=1,
            sort=InvoiceSortField.CREATED_AT,
            sort_direction=SortDirection.ASC,
            page_token="eyJ0b2tlbiI6IjEiLCJwYWdlX3Rva2VuIjoiMiJ9",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "patient_external_id": patient_external_id,
                "encounter_external_id": encounter_external_id,
                "note": note,
                "due_date_before": str(due_date_before) if due_date_before is not None else None,
                "due_date_after": str(due_date_after) if due_date_after is not None else None,
                "status": status,
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoicesPage, _response_json)  # type: ignore
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get(self, invoice_id: InvoiceId, *, request_options: typing.Optional[RequestOptions] = None) -> ImportInvoice:
        """
        Retrieve and view an import invoice

        Parameters
        ----------
        invoice_id : InvoiceId
            InvoiceId to be returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import uuid

        from candid.client import CandidApiClient

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.import_invoice.v_1.get(
            invoice_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update(
        self,
        invoice_id: InvoiceId,
        *,
        request: ImportInvoiceUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImportInvoice:
        """
        Update the information on the imported invoice

        Parameters
        ----------
        invoice_id : InvoiceId

        request : ImportInvoiceUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import datetime
        import uuid

        from candid.client import CandidApiClient
        from candid.resources.import_invoice.v_1 import (
            ImportInvoiceUpdateRequest,
            InvoiceItemInfoUpdate,
            InvoiceItemUpdateType,
        )
        from candid.resources.invoices.v_2 import (
            InvoiceItemAttributionCreate_ServiceLineId,
            InvoiceItemCreate,
            InvoiceStatus,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.import_invoice.v_1.update(
            invoice_id=uuid.UUID(
                "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
            ),
            request=ImportInvoiceUpdateRequest(
                customer_invoice_url="string",
                status=InvoiceStatus.DRAFT,
                note="string",
                due_date=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                items=InvoiceItemInfoUpdate(
                    update_type=InvoiceItemUpdateType.APPEND,
                    items=[
                        InvoiceItemCreate(
                            attribution=InvoiceItemAttributionCreate_ServiceLineId(
                                value=uuid.UUID(
                                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                                )
                            ),
                            amount_cents=1,
                        )
                    ],
                ),
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def import_invoice(
        self, *, request: CreateImportInvoiceRequest, request_options: typing.Optional[RequestOptions] = None
    ) -> ImportInvoice:
        """
        Import an existing invoice from a third party service to reflect state in Candid.

        Parameters
        ----------
        request : CreateImportInvoiceRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import asyncio
        import datetime
        import uuid

        from candid.client import AsyncCandidApiClient
        from candid.resources.import_invoice.v_1 import CreateImportInvoiceRequest
        from candid.resources.invoices.v_2 import (
            InvoiceItemAttributionCreate_ServiceLineId,
            InvoiceItemCreate,
            InvoiceStatus,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.import_invoice.v_1.import_invoice(
                request=CreateImportInvoiceRequest(
                    external_payment_account_config_id=uuid.UUID(
                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                    ),
                    patient_external_id="string",
                    external_customer_identifier="string",
                    note="string",
                    due_date=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                    items=[
                        InvoiceItemCreate(
                            attribution=InvoiceItemAttributionCreate_ServiceLineId(
                                value=uuid.UUID(
                                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                                )
                            ),
                            amount_cents=1,
                        )
                    ],
                    status=InvoiceStatus.DRAFT,
                    external_identifier="string",
                    customer_invoice_url="string",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "UnprocessableEntityError":
                raise UnprocessableEntityError(
                    pydantic_v1.parse_obj_as(UnprocessableEntityErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityConflictError":
                raise EntityConflictError(
                    pydantic_v1.parse_obj_as(EntityConflictErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_multi(
        self,
        *,
        patient_external_id: typing.Optional[PatientExternalId] = None,
        encounter_external_id: typing.Optional[EncounterExternalId] = None,
        note: typing.Optional[str] = None,
        due_date_before: typing.Optional[dt.date] = None,
        due_date_after: typing.Optional[dt.date] = None,
        status: typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]] = None,
        limit: typing.Optional[int] = None,
        sort: typing.Optional[InvoiceSortField] = None,
        sort_direction: typing.Optional[SortDirection] = None,
        page_token: typing.Optional[PageToken] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImportInvoicesPage:
        """
        Returns all Invoices for the authenticated user's organziation with all filters applied.

        Parameters
        ----------
        patient_external_id : typing.Optional[PatientExternalId]

        encounter_external_id : typing.Optional[EncounterExternalId]

        note : typing.Optional[str]
            partial match supported

        due_date_before : typing.Optional[dt.date]
            all invoices whose due date is before this due date, not inclusive

        due_date_after : typing.Optional[dt.date]
            all invoices whose due date is after this due date, not inclusive

        status : typing.Optional[typing.Union[InvoiceStatus, typing.Sequence[InvoiceStatus]]]
            all invoices that match any of the provided statuses

        limit : typing.Optional[int]
            Defaults to 100

        sort : typing.Optional[InvoiceSortField]
            Defaults to created_at

        sort_direction : typing.Optional[SortDirection]
            Sort direction. Defaults to descending order

        page_token : typing.Optional[PageToken]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoicesPage

        Examples
        --------
        import asyncio
        import datetime

        from candid import SortDirection
        from candid.client import AsyncCandidApiClient
        from candid.resources.invoices.v_2 import InvoiceSortField, InvoiceStatus

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.import_invoice.v_1.get_multi(
                patient_external_id="string",
                encounter_external_id="string",
                note="string",
                due_date_before=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                due_date_after=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                status=InvoiceStatus.DRAFT,
                limit=1,
                sort=InvoiceSortField.CREATED_AT,
                sort_direction=SortDirection.ASC,
                page_token="eyJ0b2tlbiI6IjEiLCJwYWdlX3Rva2VuIjoiMiJ9",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/import-invoice/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            params={
                "patient_external_id": patient_external_id,
                "encounter_external_id": encounter_external_id,
                "note": note,
                "due_date_before": str(due_date_before) if due_date_before is not None else None,
                "due_date_after": str(due_date_after) if due_date_after is not None else None,
                "status": status,
                "limit": limit,
                "sort": sort,
                "sort_direction": sort_direction,
                "page_token": page_token,
            },
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoicesPage, _response_json)  # type: ignore
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get(
        self, invoice_id: InvoiceId, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ImportInvoice:
        """
        Retrieve and view an import invoice

        Parameters
        ----------
        invoice_id : InvoiceId
            InvoiceId to be returned

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import asyncio
        import uuid

        from candid.client import AsyncCandidApiClient

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.import_invoice.v_1.get(
                invoice_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="GET",
            request_options=request_options,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update(
        self,
        invoice_id: InvoiceId,
        *,
        request: ImportInvoiceUpdateRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ImportInvoice:
        """
        Update the information on the imported invoice

        Parameters
        ----------
        invoice_id : InvoiceId

        request : ImportInvoiceUpdateRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ImportInvoice

        Examples
        --------
        import asyncio
        import datetime
        import uuid

        from candid.client import AsyncCandidApiClient
        from candid.resources.import_invoice.v_1 import (
            ImportInvoiceUpdateRequest,
            InvoiceItemInfoUpdate,
            InvoiceItemUpdateType,
        )
        from candid.resources.invoices.v_2 import (
            InvoiceItemAttributionCreate_ServiceLineId,
            InvoiceItemCreate,
            InvoiceStatus,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.import_invoice.v_1.update(
                invoice_id=uuid.UUID(
                    "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                ),
                request=ImportInvoiceUpdateRequest(
                    customer_invoice_url="string",
                    status=InvoiceStatus.DRAFT,
                    note="string",
                    due_date=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                    items=InvoiceItemInfoUpdate(
                        update_type=InvoiceItemUpdateType.APPEND,
                        items=[
                            InvoiceItemCreate(
                                attribution=InvoiceItemAttributionCreate_ServiceLineId(
                                    value=uuid.UUID(
                                        "d5e9c84f-c2b2-4bf4-b4b0-7ffd7a9ffc32",
                                    )
                                ),
                                amount_cents=1,
                            )
                        ],
                    ),
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"api/import-invoice/v1/{jsonable_encoder(invoice_id)}",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="PATCH",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(ImportInvoice, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class NonInsurancePayerPaymentSortField(str, enum.Enum):
    AMOUNT_CENTS = "amount_cents"
    PAYMENT_TIMESTAMP = "payment_timestamp"

    def visit(
        self, amount_cents: typing.Callable[[], T_Result], payment_timestamp: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is NonInsurancePayerPaymentSortField.AMOUNT_CENTS:
            return amount_cents()
        if self is NonInsurancePayerPaymentSortField.PAYMENT_TIMESTAMP:
            return payment_timestamp()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .clinical_note import ClinicalNote
from .note_category import NoteCategory


class ClinicalNoteCategory(pydantic.BaseModel):
    """
    Examples
    --------
    import datetime

    from candid.resources.encounters.v_4 import (
        ClinicalNote,
        ClinicalNoteCategory,
        NoteCategory,
    )

    ClinicalNoteCategory(
        category=NoteCategory.CLINICAL,
        notes=["Patient complained of mild chest pain."],
        notes_structured=[
            ClinicalNote(
                text="Mild chest pain since morning.",
                author_name="John Doe",
                author_npi="1234567890",
                timestamp=datetime.datetime.fromisoformat(
                    "2023-01-01 00:00:00+00:00",
                ),
            )
        ],
    )
    """

    category: NoteCategory
    notes: typing.List[str]
    notes_structured: typing.Optional[typing.List[ClinicalNote]] = None

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.facility_type_code import FacilityTypeCode
from .....commons.types.street_address_short_zip import StreetAddressShortZip
from .....organization_providers.resources.v_2.types.organization_provider_id import OrganizationProviderId
from .....organization_service_facilities.resources.v_2.types.organization_service_facility_id import (
    OrganizationServiceFacilityId,
)
from .expected_network_status_subscriber_information import ExpectedNetworkStatusSubscriberInformation
from .service_type import ServiceType


class ComputeAllInNetworkProvidersRequest(pydantic.BaseModel):
    service_type: ServiceType = pydantic.Field()
    """
    For some payers, payer routing depends on whether the rendered service qualifies as a behavioral health visit
    (e.g. Blue Shield of California routes to Magellan for behavioral health visits).
    
    For post appointment payer routing, Candid uses a CPT code list to determine whether the appointment qualifies as a
    behavioral health visit
    (see “Inputs: Service Type” in the appendix for list of qualifying CPT codes and behavioral health routing logic).
    Since CPT codes are not available pre-appointment, the service type input is used to determine whether the appointment is expected
    to qualify as behavioral health.
    """

    place_of_service_code: FacilityTypeCode = pydantic.Field()
    """
    Expected place of service
    """

    subscriber_information: ExpectedNetworkStatusSubscriberInformation = pydantic.Field()
    """
    Information present on the patient's insurance card
    """

    patient_address: StreetAddressShortZip
    billing_provider_id: OrganizationProviderId
    organization_service_facility_id: OrganizationServiceFacilityId = pydantic.Field()
    """
    The id of the service facility where the appointment will be rendered
    """

    date_of_service: dt.date = pydantic.Field()
    """
    Expected date of service
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.claim_id import ClaimId
from .....payers.resources.v_3.types.payer_identifier import PayerIdentifier
from .....remits.resources.v_1.types.payee import Payee
from .claim_adjudication_create import ClaimAdjudicationCreate


class InsuranceAdjudicationCreate(pydantic.BaseModel):
    payer_identifier: PayerIdentifier
    payee: Payee
    post_date: typing.Optional[dt.date] = None
    check_number: typing.Optional[str] = None
    check_date: dt.date
    note: typing.Optional[str] = None
    claims: typing.Dict[ClaimId, typing.List[ClaimAdjudicationCreate]]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.rate_id import RateId
from .rate_entry import RateEntry


class NewRateVersion(pydantic.BaseModel):
    rate_id: RateId
    previous_version: int = pydantic.Field()
    """
    New versions of rates must indicate the exact version they modify. When the system attempts to save this new version, if the latest version in the system does not equal this previos_version, the request will be rejected with a EntityConflictError.
    """

    entries: typing.List[RateEntry]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from .contact import Contact
from .external_provenance import ExternalProvenance
from .filing_order import FilingOrder
from .guarantor import Guarantor
from .marital_status import MaritalStatus
from .mutable_patient import MutablePatient
from .patient import Patient
from .patient_page import PatientPage
from .patient_sort_field import PatientSortField
from .potential_duplicate_patient import PotentialDuplicatePatient
from .potential_duplicate_patients_error_body import PotentialDuplicatePatientsErrorBody

__all__ = [
    "Contact",
    "ExternalProvenance",
    "FilingOrder",
    "Guarantor",
    "MaritalStatus",
    "MutablePatient",
    "Patient",
    "PatientPage",
    "PatientSortField",
    "PotentialDuplicatePatient",
    "PotentialDuplicatePatientsErrorBody",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DisabilityStatus(str, enum.Enum):
    DISABLED = "DISABLED"
    NON_DISABLED = "NON_DISABLED"

    def visit(self, disabled: typing.Callable[[], T_Result], non_disabled: typing.Callable[[], T_Result]) -> T_Result:
        if self is DisabilityStatus.DISABLED:
            return disabled()
        if self is DisabilityStatus.NON_DISABLED:
            return non_disabled()



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from ...commons.types.street_address_short_zip import StreetAddressShortZip
from .individual_base import IndividualBase


class PatientBase(IndividualBase):
    external_id: str = pydantic.Field()
    """
    The ID used to identify this individual in your system. For example, your internal patient ID or an EHR patient ID.
    """

    date_of_birth: dt.date = pydantic.Field()
    """
    Box 3 on the CMS-1500 claim form. The date format should be in ISO 8601 date; formatted YYYY-MM-DD (i.e. 2012-02-01)
    """

    address: StreetAddressShortZip = pydantic.Field()
    """
    Box 5 on the CMS-1500 claim form.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ....core.datetime_utils import serialize_datetime
from ....core.pydantic_utilities import deep_union_pydantic_dicts
from .tag_create import TagCreate


class Tag(TagCreate):
    """
    Examples
    --------
    from candid import Tag, TagColorEnum

    Tag(
        creator_id="00EB5A46-35C6-441B-9751-AF307AEF5888",
        tag_id="void-claim-submitted",
        description="to indicate claims where a void claim has been submitted",
        color=TagColorEnum.BLACK,
    )
    """

    creator_id: str

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts


class GetExportsResponse(pydantic.BaseModel):
    """
    Examples
    --------
    import datetime

    from candid.resources.exports.v_3 import GetExportsResponse

    GetExportsResponse(
        name="John Doe",
        created_at=datetime.datetime.fromisoformat(
            "2021-10-07 00:00:00+00:00",
        ),
        authenticated_download_url="https://example.com",
        authenticated_download_url_expiration=datetime.datetime.fromisoformat(
            "2021-10-07 00:02:00+00:00",
        ),
    )
    """

    name: str = pydantic.Field()
    """
    Report name; contains date strings representing the start and end date of the export.
    """

    created_at: dt.datetime
    authenticated_download_url: str = pydantic.Field()
    """
    Authenticated URL where a customer's report can be retrieved.
    """

    authenticated_download_url_expiration: dt.datetime = pydantic.Field()
    """
    Expiration datetime of the authenticated URL. URLs expire after 2 minutes.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ........core.datetime_utils import serialize_datetime
from ........core.pydantic_utilities import deep_union_pydantic_dicts
from .....common.types.coverage_id import CoverageId
from .....common.types.organization_id import OrganizationId
from .....common.types.user_id import UserId
from .mutable_coverage import MutableCoverage


class Coverage(MutableCoverage):
    """
    A coverage object with immutable server-owned properties.
    """

    id: CoverageId
    organization_id: OrganizationId = pydantic.Field()
    """
    The organization that owns this coverage.
    """

    deactivated: bool = pydantic.Field()
    """
    True if the coverage is deactivated. Deactivated coverages are not returned in search results but are returned in all other endpoints including scan.
    """

    version: int = pydantic.Field()
    """
    The version of the coverage. Any update to any property of a coverage object will create a new version.
    """

    updated_at: dt.datetime
    updating_user_id: UserId = pydantic.Field()
    """
    The user ID of the user who last updated the coverage.
    """

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        allow_population_by_field_name = True
        populate_by_name = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....payers.resources.v_3.types.payer import Payer
from .insurance_write_off_reason import InsuranceWriteOffReason
from .insurance_write_off_target import InsuranceWriteOffTarget
from .write_off_id import WriteOffId


class InsuranceWriteOff(pydantic.BaseModel):
    write_off_id: WriteOffId
    payer: Payer
    write_off_target: InsuranceWriteOffTarget
    write_off_timestamp: dt.datetime
    write_off_note: typing.Optional[str] = None
    write_off_reason: InsuranceWriteOffReason
    reverts_write_off_id: typing.Optional[WriteOffId] = None
    reverted_by_write_off_id: typing.Optional[WriteOffId] = None
    amount_cents: int

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

from ......core.api_error import ApiError
from .....commons.types.error_message import ErrorMessage


class MissingDailyIncrementalExportFileError(ApiError):
    def __init__(self, body: ErrorMessage):
        super().__init__(status_code=503, body=body)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic

from ......core.datetime_utils import serialize_datetime
from ......core.pydantic_utilities import deep_union_pydantic_dicts
from .....commons.types.insurance_type_code import InsuranceTypeCode


class InsuranceTypeCodes_InsuranceTypeCode(pydantic.BaseModel):
    value: InsuranceTypeCode
    type: typing.Literal["insurance_type_code"] = "insurance_type_code"

    class Config:
        frozen = True
        smart_union = True


class InsuranceTypeCodes_UnknownInsuranceTypeCode(pydantic.BaseModel):
    type: typing.Literal["unknown_insurance_type_code"] = "unknown_insurance_type_code"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


class InsuranceTypeCodes_NotApplicable(pydantic.BaseModel):
    type: typing.Literal["not_applicable"] = "not_applicable"

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults_exclude_unset: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        kwargs_with_defaults_exclude_none: typing.Any = {"by_alias": True, "exclude_none": True, **kwargs}

        return deep_union_pydantic_dicts(
            super().dict(**kwargs_with_defaults_exclude_unset), super().dict(**kwargs_with_defaults_exclude_none)
        )

    class Config:
        frozen = True
        smart_union = True
        extra = pydantic.Extra.allow
        json_encoders = {dt.datetime: serialize_datetime}


InsuranceTypeCodes = typing.Union[
    InsuranceTypeCodes_InsuranceTypeCode, InsuranceTypeCodes_UnknownInsuranceTypeCode, InsuranceTypeCodes_NotApplicable
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentStatus(str, enum.Enum):
    PENDING = "PENDING"
    NOT_READY = "NOT_READY"
    READY = "READY"
    CHECKED_IN = "CHECKED_IN"

    def visit(
        self,
        pending: typing.Callable[[], T_Result],
        not_ready: typing.Callable[[], T_Result],
        ready: typing.Callable[[], T_Result],
        checked_in: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is AppointmentStatus.PENDING:
            return pending()
        if self is AppointmentStatus.NOT_READY:
            return not_ready()
        if self is AppointmentStatus.READY:
            return ready()
        if self is AppointmentStatus.CHECKED_IN:
            return checked_in()



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .....core.api_error import ApiError
from .....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .....core.pydantic_utilities import pydantic_v1
from .....core.request_options import RequestOptions
from ....commons.errors.entity_not_found_error import EntityNotFoundError
from ....commons.errors.http_request_validation_error import HttpRequestValidationError
from ....commons.types.entity_not_found_error_message import EntityNotFoundErrorMessage
from ....commons.types.request_validation_error import RequestValidationError
from ....encounters.resources.v_4.errors.encounter_external_id_uniqueness_error import (
    EncounterExternalIdUniquenessError,
)
from ....encounters.resources.v_4.errors.encounter_patient_control_number_uniqueness_error import (
    EncounterPatientControlNumberUniquenessError,
)
from ....encounters.resources.v_4.errors.schema_instance_validation_http_failure import (
    SchemaInstanceValidationHttpFailure,
)
from ....encounters.resources.v_4.types.encounter import Encounter
from ....encounters.resources.v_4.types.encounter_external_id_uniqueness_error_type import (
    EncounterExternalIdUniquenessErrorType,
)
from ....encounters.resources.v_4.types.encounter_patient_control_number_uniqueness_error_type import (
    EncounterPatientControlNumberUniquenessErrorType,
)
from ....encounters.resources.v_4.types.schema_instance_validation_failure import SchemaInstanceValidationFailure
from .types.medication_dispense_create import MedicationDispenseCreate

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class V1Client:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create(
        self, *, request: MedicationDispenseCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> Encounter:
        """
        Parameters
        ----------
        request : MedicationDispenseCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Encounter

        Examples
        --------
        import datetime

        from candid import ProcedureModifier, ServiceLineUnits
        from candid.client import CandidApiClient
        from candid.resources.medication_dispense.v_1 import MedicationDispenseCreate
        from candid.resources.service_lines.v_2 import (
            DrugIdentification,
            MeasurementUnitCode,
            ServiceIdQualifier,
        )

        client = CandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.medication_dispense.v_1.create(
            request=MedicationDispenseCreate(
                medication_dispense_external_id="string",
                patient_external_id="string",
                procedure_code="string",
                quantity="string",
                units=ServiceLineUnits.MJ,
                date_of_service=datetime.date.fromisoformat(
                    "2023-01-15",
                ),
                drug_identification=DrugIdentification(
                    service_id_qualifier=ServiceIdQualifier.EAN_UCC_13,
                    national_drug_code="string",
                    national_drug_unit_count="string",
                    measurement_unit_code=MeasurementUnitCode.MILLILITERS,
                    link_sequence_number="string",
                    pharmacy_prescription_number="string",
                    conversion_formula="string",
                ),
                description="string",
                modifiers=[ProcedureModifier.TWENTY_TWO],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "api/medication-dispense/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Encounter, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EncounterExternalIdUniquenessError":
                raise EncounterExternalIdUniquenessError(
                    pydantic_v1.parse_obj_as(EncounterExternalIdUniquenessErrorType, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EncounterPatientControlNumberUniquenessError":
                raise EncounterPatientControlNumberUniquenessError(
                    pydantic_v1.parse_obj_as(EncounterPatientControlNumberUniquenessErrorType, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    pydantic_v1.parse_obj_as(SchemaInstanceValidationFailure, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncV1Client:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create(
        self, *, request: MedicationDispenseCreate, request_options: typing.Optional[RequestOptions] = None
    ) -> Encounter:
        """
        Parameters
        ----------
        request : MedicationDispenseCreate

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Encounter

        Examples
        --------
        import asyncio
        import datetime

        from candid import ProcedureModifier, ServiceLineUnits
        from candid.client import AsyncCandidApiClient
        from candid.resources.medication_dispense.v_1 import MedicationDispenseCreate
        from candid.resources.service_lines.v_2 import (
            DrugIdentification,
            MeasurementUnitCode,
            ServiceIdQualifier,
        )

        client = AsyncCandidApiClient(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.medication_dispense.v_1.create(
                request=MedicationDispenseCreate(
                    medication_dispense_external_id="string",
                    patient_external_id="string",
                    procedure_code="string",
                    quantity="string",
                    units=ServiceLineUnits.MJ,
                    date_of_service=datetime.date.fromisoformat(
                        "2023-01-15",
                    ),
                    drug_identification=DrugIdentification(
                        service_id_qualifier=ServiceIdQualifier.EAN_UCC_13,
                        national_drug_code="string",
                        national_drug_unit_count="string",
                        measurement_unit_code=MeasurementUnitCode.MILLILITERS,
                        link_sequence_number="string",
                        pharmacy_prescription_number="string",
                        conversion_formula="string",
                    ),
                    description="string",
                    modifiers=[ProcedureModifier.TWENTY_TWO],
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            "api/medication-dispense/v1",
            base_url=self._client_wrapper.get_environment().candid_api,
            method="POST",
            json=request,
            request_options=request_options,
            omit=OMIT,
        )
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        if 200 <= _response.status_code < 300:
            return pydantic_v1.parse_obj_as(Encounter, _response_json)  # type: ignore
        if "errorName" in _response_json:
            if _response_json["errorName"] == "HttpRequestValidationError":
                raise HttpRequestValidationError(
                    pydantic_v1.parse_obj_as(RequestValidationError, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EncounterExternalIdUniquenessError":
                raise EncounterExternalIdUniquenessError(
                    pydantic_v1.parse_obj_as(EncounterExternalIdUniquenessErrorType, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EncounterPatientControlNumberUniquenessError":
                raise EncounterPatientControlNumberUniquenessError(
                    pydantic_v1.parse_obj_as(EncounterPatientControlNumberUniquenessErrorType, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "EntityNotFoundError":
                raise EntityNotFoundError(
                    pydantic_v1.parse_obj_as(EntityNotFoundErrorMessage, _response_json["content"])  # type: ignore
                )
            if _response_json["errorName"] == "SchemaInstanceValidationHttpFailure":
                raise SchemaInstanceValidationHttpFailure(
                    pydantic_v1.parse_obj_as(SchemaInstanceValidationFailure, _response_json["content"])  # type: ignore
                )
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class DiagnosisTypeCode(str, enum.Enum):
    ABF = "ABF"
    """
    ICD-10 Diagnosis
    """

    ABJ = "ABJ"
    """
    ICD-10 Admitting Diagnosis
    """

    ABK = "ABK"
    """
    ICD-10 Principal Diagnosis
    """

    APR = "APR"
    """
    ICD-10 Patient Reason for Visit
    """

    BF = "BF"
    """
    ICD-9 Diagnosis
    """

    BJ = "BJ"
    """
    ICD-9 Admitting Diagnosis
    """

    BK = "BK"
    """
    ICD-9 Principal Diagnosis
    """

    PR = "PR"
    """
    ICD-9 Patient Reason for Visit
    """

    DR = "DR"
    """
    Diagnosis Related Group (DRG)
    """

    LOI = "LOI"
    """
    Logical Observation Identifier Names and Codes (LOINC<190>) Codes
    """

    def visit(
        self,
        abf: typing.Callable[[], T_Result],
        abj: typing.Callable[[], T_Result],
        abk: typing.Callable[[], T_Result],
        apr: typing.Callable[[], T_Result],
        bf: typing.Callable[[], T_Result],
        bj: typing.Callable[[], T_Result],
        bk: typing.Callable[[], T_Result],
        pr: typing.Callable[[], T_Result],
        dr: typing.Callable[[], T_Result],
        loi: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is DiagnosisTypeCode.ABF:
            return abf()
        if self is DiagnosisTypeCode.ABJ:
            return abj()
        if self is DiagnosisTypeCode.ABK:
            return abk()
        if self is DiagnosisTypeCode.APR:
            return apr()
        if self is DiagnosisTypeCode.BF:
            return bf()
        if self is DiagnosisTypeCode.BJ:
            return bj()
        if self is DiagnosisTypeCode.BK:
            return bk()
        if self is DiagnosisTypeCode.PR:
            return pr()
        if self is DiagnosisTypeCode.DR:
            return dr()
        if self is DiagnosisTypeCode.LOI:
            return loi()



# This file was auto-generated by Fern from our API Definition.

from ....core.api_error import ApiError
from ..types.unprocessable_entity_error_message import UnprocessableEntityErrorMessage


class UnprocessableEntityError(ApiError):
    def __init__(self, body: UnprocessableEntityErrorMessage):
        super().__init__(status_code=422, body=body)



# This file was auto-generated by Fern from our API Definition.

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .resources.appointments.client import AppointmentsClient, AsyncAppointmentsClient
from .resources.coverages.client import AsyncCoveragesClient, CoveragesClient
from .resources.lists.client import AsyncListsClient, ListsClient
from .resources.patients.client import AsyncPatientsClient, PatientsClient


class PreEncounterClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.appointments = AppointmentsClient(client_wrapper=self._client_wrapper)
        self.coverages = CoveragesClient(client_wrapper=self._client_wrapper)
        self.lists = ListsClient(client_wrapper=self._client_wrapper)
        self.patients = PatientsClient(client_wrapper=self._client_wrapper)


class AsyncPreEncounterClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper
        self.appointments = AsyncAppointmentsClient(client_wrapper=self._client_wrapper)
        self.coverages = AsyncCoveragesClient(client_wrapper=self._client_wrapper)
        self.lists = AsyncListsClient(client_wrapper=self._client_wrapper)
        self.patients = AsyncPatientsClient(client_wrapper=self._client_wrapper)
